==============
 zope.catalog
==============

Interfaces
==========

.. automodule:: zope.catalog.interfaces

Catalog
=======

.. automodule:: zope.catalog.catalog

Index Implementations
=====================

The implementations of various kinds of indexes are spread across a
few modules.

Attribute Indexes
-----------------

.. automodule:: zope.catalog.attribute

Field Indexes
-------------

.. automodule:: zope.catalog.field

Keyword Indexes
---------------

.. automodule:: zope.catalog.keyword

Text Indexes
------------

.. automodule:: zope.catalog.text
